# Project Converter Implementations <!-- omit in toc -->

- [Overview](#overview)
- [Project Converter Class Diagram](#project-converter-class-diagram)

## Overview

This folder adds project specifc converters for the pyTRCLConverter model files in
[trlc/model](../../trlc/model/). The coverters build hierarchies based on model file
include dependencies:

## Project Converter Class Diagram

This diagrams shows the relations between the converter classes:

![context](https://www.plantuml.com/plantuml/proxy?cache=no&src=https://raw.githubusercontent.com/NewTec-GmbH/pyTRLCConverter/refs/heads/main/tools/ProjectConverter/project_converter_class_diagram.puml)
